/* DirView.qml  -- Directory view class for Scriptomatix */
/*
   Copyright (C) 2007-2018 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1

Item {
    property alias sx_dirview: sx_dirview
    property bool ready: false
    anchors.top: parent.top
    Layout.fillWidth: true
    Layout.maximumHeight: parent.height/2
    anchors.margins: 2
    anchors.horizontalCenter: parent.horizontalCenter
    height: scriptomatix.sx_nbLineDir*scriptomatix.sx_cellHeight
    Rectangle {
        anchors.fill: sx_dirview
        radius: 5.0
        color: sx_palette.alternateBase
        border.color: sx_palette.mid
        border.width: (sx_dirview.focus) ? 2 : 1
    }
    GridView {
        id: sx_dirview
        anchors.fill: parent
        anchors.margins: 2
        cellHeight: scriptomatix.sx_cellHeight
        cellWidth: scriptomatix.sx_cellWidth
        opacity: (enabled) ? 1.0 : 0.5
        clip: true
        model: ListModel { }
        delegate: Item {
            property string mypath: path
            property string myicon: icon
            width: scriptomatix.sx_cellWidth
            height: scriptomatix.sx_cellHeight
            Image {
                id: sx_diricon
                width: 48
                height: 48
                anchors.horizontalCenter: parent.horizontalCenter
                source: (myicon.match(/^\//)) ? "file:/"+myicon : "file://"+mypath+"/"+myicon // absolute or relative path
            }
            Text {
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: sx_diricon.bottom
                text: title
                font.pixelSize: 11
            }
        }
        highlightFollowsCurrentItem: true
        highlight: Component {
            Rectangle {
                color: sx_palette.highlight
                opacity: 0.7
                radius: 5.0
                y: (sx_dirview.currentIndex != -1) ? sx_dirview.currentItem.y : 0
                Behavior on y { SpringAnimation { spring: 3; damping: 0.2 } }
            }
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                parent.focus = true;
                var idx = sx_dirview.indexAt(mouseX+sx_dirview.contentX,mouseY+sx_dirview.contentY);
                if (idx !== -1) sx_dirnum = sx_dirview.currentIndex = idx;
            }
        }
        onCurrentIndexChanged: {
            if (currentIndex != -1) {
                scriptChanged(sx_dirview.currentItem.mypath+"/Scripts.qml");
            }
        }
    }
    onHeightChanged: {
        if (state === "opened") {
            if (ready)
                scriptomatix.sx_nbLineDir = Math.round(height/scriptomatix.sx_cellHeight);
            height = scriptomatix.sx_nbLineDir*scriptomatix.sx_cellHeight+2*anchors.margins;
        } else height = 0;
    }
    transform: Scale {
        id: sx_plierdir
        yScale: 0.0
        origin.y: 0
    }
    states: [
        State {
            name: ""
            PropertyChanges { target: sx_plierdir; yScale: 0.0 }
            PropertyChanges { target: sx_menudir; height: 0 }
            StateChangeScript {
                script: sx_menudir.enabled = false;
            }
        },
        State {
            name: "opened"
            PropertyChanges { target: sx_plierdir; yScale: 1.0 }
            PropertyChanges { target: sx_menudir; height: scriptomatix.sx_nbLineDir*scriptomatix.sx_cellHeight }
            StateChangeScript {
                script: sx_menudir.enabled = true;
            }
        }
    ]
}


