/* Help.qml  -- Help pages class for Scriptomatix */
/*
   Copyright (C) 2007-2018 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QtQuick.Dialogs 1.0
import QtQuick.Controls.Styles 1.3
import QmlFile 0.1

Rectangle {
    id: sx_aide
    anchors.fill: parent
    anchors.margins: 4
    color: sx_palette.window
    border.color: sx_palette.mid
    border.width: 1
    radius: 10.0
    enabled: false
    property var titles: [ qsTr("About"), qsTr("First use"), qsTr("Toolbar"), qsTr("Scripts file"), qsTr("Parameters"), qsTr("Builtin features"), qsTr("Root usage"), qsTr("Credits")]
    property var pages: [ "about.html", "first.html", "tools.html", "scripts.html", "params.html", "builtin.html", "root.html", "credits.html" ]
    property string language : Qt.locale().nativeLanguageName.substr(0,2)
//    property string language : "en"

    function  setHelp(fname) {
        io.setSource(dataPath+"help/"+language+"/"+fname);
        if (io.exists()) {
            helpContent.cursorPosition = 0;
            io.read();
            helpContent.text = io.text.replace(/\.\.\/\.\./g,dataPath);
        } else {
            helpContent.text = qsTr("File not found : ")+io.source;
        }
    }

    ColumnLayout {
        anchors.fill: parent
        anchors.margins: 10
        spacing: 5
        anchors.horizontalCenter: parent.horizontalCenter
        Layout.alignment: Qt.AlignTop
        RowLayout {
            Layout.fillWidth: true
            Text {
                text: "Build : "+app_build;
                font { pixelSize: 10;}
                opacity: 0.3
            }
            Text {
                Layout.fillWidth: true
                Layout.rightMargin: butclose.width + 20
                text: sx_app_name+" "+app_version;
                font { pixelSize: 22; bold: true }
                horizontalAlignment: Text.AlignHCenter
            }
        }
        ExclusiveGroup { id: helpgroup }
        RowLayout {
            Repeater {
                model: pages
                Button {
                    exclusiveGroup: helpgroup
                    text: titles[index]
                    checkable: true
                    checked: (index === 0)
                    onCheckedChanged: if (checked)  setHelp(modelData);
                }
            }
        }

        TextArea {
            id: helpContent
            Layout.fillWidth: true
            Layout.fillHeight: true
            onLinkActivated: Qt.openUrlExternally(link)
            textFormat: Text.RichText
            readOnly: true
            wrapMode: Text.WordWrap
            font { pixelSize: 12 }
            text: "helpcontent"
            style: TextAreaStyle { renderType: Text.QtRendering }         // Avoid display bug when scrolling with mouse.
        }
    }

    FileIO { id: io }
    Button {
        id: butclose
        anchors.top: parent.top
        anchors.right: parent.right
        anchors.margins: 10
        width: 100
        height: 25
        iconSource: "file:/"+dataPath+"icons/dialog-close.png"
        text: qsTr("Close")
        tooltip: qsTr("Close help")
        onClicked: parent.state = "";
    }
    Keys.onEscapePressed: state = "";

    transform: Scale {
        id: plier
        yScale: 0.0
        xScale: 0.0
        origin.x: parent.width
        origin.y: 0
    }
    states: [
        State {
            name: ""
            PropertyChanges { target: plier; xScale: 0.0; yScale: 0.0 }
            StateChangeScript {
                script: {
                    focus = false;
                    enabled = false;
                    toolBar.enabled = true;
                    sx_menudir.enabled = true;
                    sx_mainContent.enabled = true;
                }
            }
        },
        State {
            name: "opened"
            PropertyChanges { target: plier; xScale: 1.0; yScale: 1.0 }
            StateChangeScript {
                script: {
                    toolBar.enabled = false;
                    sx_menudir.enabled = false;
                    sx_mainContent.enabled = false;
                    enabled = true;
                    focus = true;
                }
            }
        }
    ]
    transitions: [
        Transition {
            from: ""; to: "opened"
            reversible: true
            NumberAnimation { target: plier; properties: "xScale,yScale"; duration: 700 }
        }
    ]
    Component.onCompleted: {
        setHelp(pages[0]);
    }
}

