/* ScriptView.qml  -- Script view class for Scriptomatix */
/*
   Copyright (C) 2007-2018 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1

Item {
    property alias sx_scriptview: sx_scriptview
    property bool ready: false
    Layout.fillHeight: true
    Layout.minimumWidth: 2*sx_scriptview.anchors.margins+scriptomatix.sx_cellWidth
    Layout.maximumWidth: parent.width/2
    width: 2*sx_scriptview.anchors.margins+scriptomatix.sx_nbColumnScript*scriptomatix.sx_cellWidth
    anchors.topMargin: 3
    Rectangle {
        anchors.fill: sx_scriptview
        radius: 5.0
        color: sx_palette.alternateBase
        border.color: sx_palette.mid
        border.width: (sx_scriptview.focus) ? 2 : 1
    }
    GridView {
        id: sx_scriptview
        property alias scriptdelegate: scriptdelegate
        property alias emptyscriptdelegate: emptyscriptdelegate
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.margins: 3
        cellHeight: scriptomatix.sx_cellHeight
        cellWidth: scriptomatix.sx_cellWidth
        width: scriptomatix.sx_nbColumnScript*scriptomatix.sx_cellWidth
        anchors.fill: parent
        clip: true
        focus: true
        opacity: (enabled) ? 1.0 : 0.5
        model: ListModel {
            property string title: qsTr("Empty list");
            property bool   batch: false
            property string scripticon: "file:/"+dataPath+"icons/error.png"
            property string shell: "/bin/bash"
        }
        ScriptDelegate { id: scriptdelegate	}
        EmptyScriptDelegate  { id: emptyscriptdelegate	}
        delegate: emptyscriptdelegate
        highlightFollowsCurrentItem: true
        highlight: Component {
            Rectangle {
                color: sx_palette.highlight
                opacity: 0.7
                radius: 5.0
                y: (sx_scriptview.currentIndex != -1) ? sx_scriptview.currentItem.y : 0
                Behavior on y { SpringAnimation { spring: 3; damping: 0.2 } }
            }
        }
        MouseArea {
            anchors.fill: parent
            onClicked: {
                parent.focus = true;
                var idx = sx_scriptview.indexAt(mouseX+sx_scriptview.contentX,mouseY+sx_scriptview.contentY);
                if (idx !== -1) sx_scriptview.currentIndex = idx;
            }
        }
        Keys.onPressed: {
            event.accepted = true;
            switch (event.key) {
            case Qt.Key_Enter :
            case Qt.Key_Return : sx_execAction.trigger(); break;
            default :            event.accepted = false;  break;
            }
        }
        onCurrentIndexChanged: {
            if (currentIndex !== -1) {
                sx_stdio.cmd.text = currentItem.cmd;
                sx_scriptargs = "";
                if (sx_parameters.pannel != null) {
                    sx_parameters.pannel.destroy();
                    sx_parameters.pannel = null;
                    sx_parameters.width  = 0;
                }
                if (sx_batchnum == -1) sx_stdio.clear();
                if (currentItem.args !== "") { // Load specific sx_parameters module if exists
                    sx_io.source = sx_scriptpath+"/"+currentItem.args;
                    if (sx_io.exists()) {
                        sx_io.read();
                        try {
                            sx_parameters.pannel = Qt.createQmlObject(sx_io.text, sx_parameters, currentItem.args);
                            sx_parameters.width   = sx_parameters.pannel.requiredWidth+5;
                            sx_parameters.Layout.preferredWidth = sx_parameters.width;
                        } catch(error) {
                            sx_stdio.clear();
                            sx_stdio.error.addText(error);
                            sx_parameters.width   = 0;
                        }
                    } else {
                        sx_stdio.clear();
                        sx_stdio.error.addText(qsTr("File %1 not found.").arg(sx_io.source)+"\n");
                        sx_parameters.width   = 0;
                    }
                } else {
                    sx_parameters.width   = 0;
                }
                updateHelp(currentItem); // Help on mouse/keyboard selection
                sx_stdio.visible = currentItem.showtty;
                sx_runallAction.enabled = model.batch;
            }
        }
    }
    onWidthChanged: {
        if (ready)
            scriptomatix.sx_nbColumnScript = Math.round(width/scriptomatix.sx_cellWidth);
        width = 2*sx_scriptview.anchors.margins+scriptomatix.sx_nbColumnScript*scriptomatix.sx_cellWidth;
    }
}
