/* Source.qml  -- Source viewer for Scriptomatix */
/*
   Copyright (C) 2007-2018 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QtQuick.Dialogs 1.0
import QtQuick.Controls.Styles 1.3
import QmlProcess 0.1

Rectangle {
    id: sx_source
    anchors.fill: parent
    anchors.margins: 4
    color: sx_palette.window
    border.color: sx_palette.mid
    border.width: 1
    radius: 10.0
    enabled: false

    function  setSourceCode(num) {
        sourceCode.cursorPosition = 0;
        sourceCode.text = "";
        var file = "";
        switch (num) {
        case 1  : file = (sx_menuscript.sx_scriptview.currentItem.args !== "") ? sx_scriptpath+"/"+sx_menuscript.sx_scriptview.currentItem.args : "";  break;
        case 2  : file = sx_scriptpath+"/Scripts.qml";                      break;
        default :
            var cmdline = sx_menuscript.sx_scriptview.currentItem.cmd;
            cmdline = cmdline.replace(/\s.*/,'');       // Delete fixed arguments from command line
            cmdline = cmdline.replace(/^\.\//,'');      // Delete reference to current path
            file = sx_scriptpath+"/"+cmdline;
            break;
        }
        codeName.text = file;
        sx_io. setSource(file);
        if (sx_io.source !== "") {
            if (sx_io.exists()) {
                sourceCode.cursorPosition = 0;
                sx_io.read();
                sourceCode.text = sx_io.text.replace(/\t/g,"    ");
            } else {
                if (num === 0) {    // Check for unix commands
                    which.command = "which "+cmdline;
                    if (!which.running()) which.start();
                }
                else
                    sourceCode.text = qsTr("%1 doesn't exist").arg(sx_io.source);
            }
        } else
            sourceCode.text = qsTr("No parameters pannel");
        if (num === 2) {    // Select current item script description
            var pos = sx_menuscript.sx_scriptview.currentIndex;
            var start = 0;
            while (pos>=0) {
                start = sourceCode.text.indexOf("ListElement",start+1);
                pos--;
            }
            var end = 1+sourceCode.text.indexOf("}",start);
            sourceCode.select(start,end);
        }
    }

    Process {
        id: which
        shell: "/bin/bash"
        onFinished: {
            var cmdline = sx_menuscript.sx_scriptview.currentItem.cmd;
            cmdline = cmdline.replace(/\s.*/,'');       // Delete fixed arguments from command line
            cmdline = cmdline.replace(/^\.\//,'');      // Delete reference to current path
            if (exitCode === 0)
                sourceCode.text = qsTr("%1 is a Unix command").arg(cmdline);
            else
                sourceCode.text = qsTr("%1 doesn't exist").arg(sx_io.source);
        }
    }
    ColumnLayout {
        anchors.fill: parent
        anchors.margins: 10
        spacing: 5
        anchors.horizontalCenter: parent.horizontalCenter
        Layout.alignment: Qt.AlignTop
        Text {
            text: qsTr("Sources : %1").arg(sx_menuscript.sx_scriptview.currentItem.label)
            anchors.horizontalCenter: parent.horizontalCenter
            Layout.fillWidth: true
            height: 28
            font { pixelSize: 18; bold: true }
            horizontalAlignment: Text.AlignHCenter
        }
        ExclusiveGroup { id: srcgroup }
        RowLayout {
            Button {
                id: firstsrc
                exclusiveGroup: srcgroup
                iconSource: "file:/"+dataPath+"icons/view-scripts-file.png"
                text: qsTr("Scripts set source (Qml)")
                checkable: true
                onCheckedChanged: if (checked)  setSourceCode(2);
            }
            Button {
                exclusiveGroup: srcgroup
                iconSource: "file:/"+dataPath+"icons/view-code.png"
                text: qsTr("Pannel source (Qml)")
                checkable: true
                onCheckedChanged: if (checked)  setSourceCode(1);
            }
            Button {
                exclusiveGroup: srcgroup
                iconSource: "file:/"+dataPath+"icons/view-source.png"
                text: qsTr("Command source")
                checkable: true
                onCheckedChanged: if (checked)  setSourceCode(0);
            }
            TextField {
                id: codeName
                clip: true
                Layout.fillWidth: true
                horizontalAlignment: Text.AlignRight
                font.pixelSize: 12
                readOnly: true
                opacity: 0.8
            }
        }

        TextArea {
            id: sourceCode
            Layout.fillWidth: true
            Layout.fillHeight: true
            wrapMode: Text.WordWrap
            font { family: "monospace"; pixelSize: 12}
            readOnly: true
            style: TextAreaStyle { renderType: Text.QtRendering }         // Avoid display bug when scrolling with mouse.
        }
    }

    Button {
        anchors.top: parent.top
        anchors.right: parent.right
        anchors.margins: 10
        width: 100
        height: 25
        iconSource: "file:/"+dataPath+"icons/dialog-close.png"
        text: qsTr("Close")
        tooltip: qsTr("Close code window")
        onClicked: parent.state = "";
    }
    Keys.onEscapePressed: state = "";

    transform: Scale {
        id: plier
        yScale: 0.0
        xScale: 0.0
        origin.x: parent.width/2
        origin.y: 0
    }
    states: [
        State {
            name: ""
            PropertyChanges { target: plier; xScale: 0.0; yScale: 0.0 }
            StateChangeScript {
                script: {
                    focus = false;
                    enabled = false;
                    toolBar.enabled = true;
                    sx_menudir.enabled = true;
                    sx_mainContent.enabled = true;
                }
            }
        },
        State {
            name: "opened"
            PropertyChanges { target: plier; xScale: 1.0; yScale: 1.0 }
            StateChangeScript {
                script: {
                    firstsrc.checked = true;
                    setSourceCode(2);
                    toolBar.enabled = false;
                    sx_menudir.enabled = false;
                    sx_mainContent.enabled = false;
                    enabled = true;
                    focus = true;
                }
            }
        }
    ]
    transitions: [
        Transition {
            from: ""; to: "opened"
            reversible: true
            NumberAnimation { target: plier; properties: "xScale,yScale"; duration: 300 }
        }
    ]
}

