/* Stdio.qml  -- Stdin/stdou/stderr display for Scriptomatix */
/*
   Copyright (C) 2007-2018 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Layouts 1.1
import QmlProcess 0.1

SplitView {
    property alias cmd:    cmd
    property alias output: output
    property alias error:  error
    property alias running:  tempo.running
    property alias shell: qprocess.shell
    property int startime: 0
    property int processtime: 0
    property string mesg: ""

    signal ended ()

    orientation: Qt.Vertical
    opacity: (running) ? 0.7 : 1.0;

    function updateOutputs() {
        output.addText(qprocess.readAllStandardOutput());
        error.addText(qprocess.readAllStandardError());
        var date = new Date;
        processtime = (date.getTime()/1000)-startime;
    }

    function start(path, clrscr, addtime) {
        output.textColor = sx_palette.text;
        if (clrscr) clear();
        if (addtime) qprocess.command = "cd \""+path+"\";time " + cmd.text;
        else         qprocess.command = "cd \""+path+"\"; " + cmd.text;
        tempo.start();
        var date = new Date;
        startime = date.getTime()/1000;
        processtime = 0;
        qprocess.start();
    }

    function kill() {
        sx_batchnum = -1;
        mesg = "\nSIGKILL received\n";
        qprocess.kill();
    }

    function terminate() {
        sx_batchnum = -1;
        mesg = "\nSIGSTOP received\n";
        qprocess.terminate();
    }

    function clear() {
        output.cursorPosition = 0;
        error.cursorPosition = 0;
        output.text = ""
        error.text  = "";
        processtime = 0;
        mesg = "";
    }

    function resizeTerminal(event,disp) {
        switch (event.key) {
        case Qt.Key_Plus  :  if (disp.font.pixelSize<25) disp.font.pixelSize++; break;
        case Qt.Key_Minus :  if (disp.font.pixelSize>6)  disp.font.pixelSize--; break;
        case Qt.Key_0     :  disp.font.pixelSize = 12; break;
        default : break;
        }
    }

    Termout {
        id: cmd
        name: "Stdin"
        Layout.minimumHeight: 3*font.pixelSize
        Layout.maximumHeight: parent.height/8;
    }
    Termout {
        id: output
        name: "Stdout"
        Layout.fillHeight: true
        Layout.minimumHeight: 100
    }
    Termout {
        id: error
        name: "Stderr"
        textColor: "red"
        Layout.minimumHeight: 5*font.pixelSize
        Layout.maximumHeight: 2*parent.height/7;
    }
    Process {
        id: qprocess
        shell: "/bin/bash"
        command: ""
        onFinished: {
            updateOutputs();
            tempo.stop();
            if (mesg !== "") {
                error.addText(mesg);
                error.cursorPosition = error.text.length;
            }
            ended();  // emit signal
        }
    }
    Timer {
        id: tempo
        interval: 1000
        running: false
        repeat: true
        onTriggered: updateOutputs();
    }
}
