/* Termout.qml  -- Terminal display for Scriptomatix */
/*
   Copyright (C) 2007-2018 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Controls 1.3
import QtQuick.Controls.Styles 1.4
import QtQuick.Layouts 1.1
import QtQuick.Dialogs 1.2
import QmlFile 0.1

TextArea {
    id: term
    property string name: ""
    text: ""
    font { family: "monospace"; pixelSize: 12 }
    readOnly: true
    wrapMode: TextEdit.NoWrap
    style: TextAreaStyle { renderType: Text.QtRendering }         // Avoid display bug when scrolling with mouse.

    function addText(txt) { // Add text, handle scroll position, remember selection
        var memy     = term.contentItem.contentY;
        var memstart = term.selectionStart;
        var memend   = term.selectionEnd;
        var scrollcursor = (term.contentHeight < (term.height+term.contentItem.contentY+font.pixelSize));
        term.deselect();
        text += txt;
        if (memstart)
            if (memstart !== memend)
                term.select(memstart, memend);
        if (scrollcursor) term.contentItem.contentY = Math.max(term.contentHeight-term.height+3,0);
        else              term.contentItem.contentY = memy;
    }

    Rectangle {
        id: infoback
        anchors.fill: terminfo
        anchors.margins: -3
        radius: 3
        opacity: 0.2
        border {width: 1; color: sx_palette.dark;}
        color: sx_palette.base
    }
    Row {
        id: terminfo
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.margins: 3
        anchors.rightMargin: 25
        opacity: 0.2
        Image {
            width: 16
            height: 16
            fillMode: Image.Stretch
            source: "file:/"+dataPath+"icons/save.png"
        }
        Text {
            text: name+qsTr("\n%1 line%2").arg(term.lineCount).arg((term.lineCount<2) ? "" : "s");
            font.pixelSize: 11
            horizontalAlignment: Text.AlignRight
        }
    }
    MouseArea {
        anchors.fill: terminfo
        hoverEnabled: true
        onEntered: { terminfo.opacity = 1.0; infoback.opacity = 1.0; }
        onExited:  { terminfo.opacity = 0.2; infoback.opacity = 0.2; }
        onClicked: if (!sx_stdio.running) sx_saveDialog.open();         // Don't save while process is running
    }
//    onHeightChanged: height = Math.round(height/font.pixelSize)*term.font.pixelSize;
    Keys.onPressed: resizeTerminal(event,this);

    FileIO { id: io }
    FileDialog {
        id: sx_saveDialog
        title: qsTr("Save as...")
        selectExisting: false
        nameFilters: [ "*" ]
        modality: Qt.WindowModal
        onAccepted: {
            io.setSource(fileUrl.toString().replace(/file:\/\//,''));       // Delete protocol
            io.setText(term.text);
            io.write();
        }
    }
}
