/* main.cpp  -- Main C++ program for Scriptomatix */
/*
   Copyright (C) 2007-2017 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <QApplication>
#include <QQmlApplicationEngine>
#include <QtQml>
#include "qml_process.h"
#include "fileio.h"
#include "shellenv.h"
#include "app_version.h"


int main(int argc, char *argv[])
{
    QApplication app(argc, argv);
    app.setOrganizationName("BeRoot");
    app.setOrganizationDomain("be.root.free.fr");
    app.setApplicationName("Scriptomatix");
    app.setApplicationVersion(APP_VERSION);

    qmlRegisterType<QmlProcess>("QmlProcess", 0, 1, "Process");
    qmlRegisterType<FileIO>("QmlFile", 0, 1, "FileIO");
    qmlRegisterType<ShellEnv>("QmlEnvVars", 0, 1, "ShellEnv");

    // Remember user name
    QString userName = qgetenv("USER");
    if (userName.isEmpty())
        userName = qgetenv("USERNAME");

    // Open translations
    QTranslator qtTranslator;
    if (qtTranslator.load(":/scriptomatix_" + QLocale::system().name()))
        app.installTranslator(&qtTranslator);
    else qDebug() << "Translation file not found";

    // Parse command line
    QCommandLineParser parser;
    parser.addHelpOption();
    parser.setApplicationDescription(QObject::tr("Script launcher for Unix systems. Based on Qt/Qml framework (http://doc.qt.io/qt-5/).\n"
                                     "\tEach script is displayed with an icon, a title and optional parameters pannel.\n"
                                     "\tScripts sets are easily customizable.\n\tOct 2015/Mar 2018."
                                     "\nWeb site : http://be.root.free.fr/"));
    parser.addVersionOption();
    // Process the actual command line arguments given by the user
    parser.process(app);
    bool edit = (userName == "root") ? false : true;        // Simple user can edit scripts groups, not root

    // Set Qml application globals
    QQmlApplicationEngine engine;
    engine.rootContext()->setContextProperty("app_version", APP_VERSION);
    engine.rootContext()->setContextProperty("app_build", APP_BUILD);
    engine.rootContext()->setContextProperty("editable", edit);
    if (QGuiApplication::applicationDirPath()=="/usr/bin")  // Installed version
        engine.rootContext()->setContextProperty("dataPath", "/usr/share/scriptomatix/");
    else                                                    // Development version
        engine.rootContext()->setContextProperty("dataPath", QGuiApplication::applicationDirPath()+"/");
    engine.load(QUrl(QStringLiteral("qrc:/main.qml")));

    return app.exec();
}
