/* qml_process.cpp  -- QProcess launcher Qml for Scriptomatix */
/*
   Copyright (C) 2007-2018 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "qml_process.h"

#include <QtCore/QProcess>

class QmlProcess::Private : public QProcess
{
    Q_OBJECT
public:
    Private(QmlProcess *parent);

    QString shell;
    QString command;
private:
    QmlProcess *q;
};

QmlProcess::Private::Private(QmlProcess *parent)
    : QProcess(parent)
    , q(parent)
{
    connect(this, SIGNAL(started()), q, SIGNAL(started()));
    connect(this, SIGNAL(finished(int,QProcess::ExitStatus)), q, SIGNAL(finished(int)));
    connect(this, SIGNAL(readyReadStandardOutput()), q, SIGNAL(readyReadStandardOutput()));
    connect(this, SIGNAL(readyReadStandardError()), q, SIGNAL(readyReadStandardError()));
}

QmlProcess::QmlProcess(QObject *parent)
    : QObject(parent)
    , d(new Private(this))
{
   d->shell = "bash";
}

QmlProcess::~QmlProcess()
{
}

const QString &QmlProcess::shell() const
{
    return d->shell;
}

void QmlProcess::setShell(const QString &shell)
{
    if (shell == d->shell) return;
    d->shell = shell;
    emit shellChanged(d->shell);
}

const QString &QmlProcess::command() const
{
    return d->command;
}

bool QmlProcess::running()
{
    return (d->state() != QProcess::NotRunning);
}

void QmlProcess::setCommand(const QString &command)
{
    if (command == d->command) return;
    d->command = command;
    emit commandChanged(d->command);
}

void QmlProcess::start()
{
    d->start(d->shell);

    d->write(d->command.toUtf8().constData());
    d->closeWriteChannel();

}

void QmlProcess::terminate()
{
    d->terminate();
}

void QmlProcess::kill()
{
    d->kill();
}

QByteArray QmlProcess::readAllStandardError()
{
    return d->readAllStandardError();
}

QByteArray QmlProcess::readAllStandardOutput()
{
    return d->readAllStandardOutput();
}

#include "qml_process.moc"
