/* qml_process.h  -- QProcess launcher Qml for Scriptomatix */
/*
   Copyright (C) 2007-2018 Bruno ANSELME <be.root@free.fr>

   This file is part of the Scriptomatix software.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License v3 for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef QMLPROCESS_H
#define QMLPROCESS_H

#include <QtCore/QObject>
#include <QtCore/QStringList>

class QmlProcess : public QObject
{
    Q_OBJECT
    Q_DISABLE_COPY(QmlProcess)
    Q_PROPERTY(QString shell READ shell WRITE setShell NOTIFY shellChanged)
    Q_PROPERTY(QString command READ command WRITE setCommand NOTIFY commandChanged)
public:
    QmlProcess(QObject *parent = 0);
    ~QmlProcess();
    const QString &shell() const;
    const QString &command() const;

    Q_INVOKABLE QByteArray readAllStandardError();
    Q_INVOKABLE QByteArray readAllStandardOutput();
    Q_INVOKABLE bool running();

public slots:
    void setShell(const QString &shell);
    void setCommand(const QString &command);

    void start();
    void terminate();
    void kill();

signals:
    void shellChanged(const QString &shell);
    void commandChanged(const QString &command);

    void finished(int exitCode);
    void readyReadStandardError();
    void readyReadStandardOutput();
    void started();

private:
    class Private;
    Private *d;
};

#endif // QMLPROCESS_H

